==> libpappsomspp_0.8.15.orig.tar.gz: libpappsomspp-0.8.15/src/pappsomspp/fasta/fastaoutputstream.cpp <==

/*******************************************************************************
 * Copyright (c) 2015 Olivier Langella <Olivier.Langella@moulon.inra.fr>.
 *
 * This file is part of the PAPPSOms++ library.
 *
 *     PAPPSOms++ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     PAPPSOms++ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with PAPPSOms++.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contributors:
 *     Olivier Langella <Olivier.Langella@moulon.inra.fr> - initial API and
 *implementation
 ******************************************************************************/
#include "fastaoutputstream.h"

namespace pappso
{
FastaOutputStream::FastaOutputStream(QTextStream &otxtstream)
  : m_ofastastream(otxtstream)
{
}

FastaOutputStream::~FastaOutputStream()
{
}

void
FastaOutputStream::writeProtein(const Protein &protein)
{

  m_ofastastream << ">" << protein.getAccession() << " "
                 << protein.getDescription() << endl;
  m_ofastastream << protein.getSequence() << endl;
}

} // namespace pappso

==> libpappsomspp_0.9.38.orig.tar.gz: libpappsomspp-0.9.38/src/pappsomspp/fasta/fastaoutputstream.cpp <==

/*******************************************************************************
 * Copyright (c) 2015 Olivier Langella <Olivier.Langella@moulon.inra.fr>.
 *
 * This file is part of the PAPPSOms++ library.
 *
 *     PAPPSOms++ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     PAPPSOms++ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with PAPPSOms++.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contributors:
 *     Olivier Langella <Olivier.Langella@moulon.inra.fr> - initial API and
 *implementation
 ******************************************************************************/
#include "fastaoutputstream.h"

namespace pappso
{
FastaOutputStream::FastaOutputStream(QTextStream &otxtstream)
  : m_ofastastream(otxtstream)
{
}

FastaOutputStream::~FastaOutputStream()
{
}

void
FastaOutputStream::writeProtein(const Protein &protein)
{

  m_ofastastream << ">" << protein.getAccession() << " "
                 << protein.getDescription() << Qt::endl;
  m_ofastastream << protein.getSequence() << Qt::endl;
}

} // namespace pappso
